"""transversal building blocs for lg-rez

Each file in this module serves a specific purpose unrelated to Discord
commands: database connection, Google Sheets operations, environement variables
management, utility tools...
"""

__all__ = ["bdd_tools", "bdd", "env", "gsheets", "pseudoshell", "tools", "webhook"]
